@@ -6,13 +6,21 @@ if(getRversion() >= "2.15.1")  utils::globalVariables(c("track_url", "lyrics"))
 #'
 #' @param artist The quoted name of the artist. Spelling matters, capitalization does not.
 #' @param album The quoted name of the album Spelling matters, capitalization does not.
-#' @param info Return extra information about each song. Default `"simple"` returns `title`, `track_n`, and `text`. Set `info = "artist"` for artist and track title. See args to `genius_lyrics()`.
+#' @param info Return track level metadata. See details.
+#'
+#' @details
+#' The `info` argument returns additional columns to the returned tibble:
+#' `"simple"` returns only the song lyrics.
+#' `"title"` returns the track title and lyrics.
+#' `"artist"` returns the lyrics and artist.
+#' `"features"` returns the lyrics, song elements, and element artists.
+#' `"all"` returns all of the above mentioned, plus appends the album name.
 #'
 #' @examples
 #'
 #'\dontrun{
 #' genius_album(artist = "Petal", album = "Comfort EP")
-#' genius_album(artist = "Fit For A King", album = "Deathgrip")
+#' genius_album(artist = "Fit For A King", album = "Deathgrip", info = "all")
 #'}
 #'
 #' @export
@@ -27,10 +35,12 @@ genius_album <- function(artist = NULL, album = NULL, info = "simple") {
 
   album <- tracks %>%
     mutate(lyrics = map(track_url, possible_url, info)) %>%
+    select(-track_title) %>%
     unnest(lyrics) %>%
     right_join(tracks) %>%
     select(-track_url)
 
+  if(info != "all"){album <- album %>% select(-.data$album_name)}
 
   return(album)
 }
